==> kadu_0.5.0.orig.tar.gz: kadu/modules/migration/translations/migration_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MigrationDialog</name>
    <message>
        <source>Migration</source>
        <translation>Migration</translation>
    </message>
    <message>
        <source>Migration steps</source>
        <translation> Les étapes de migration</translation>
    </message>
    <message>
        <source>Migration in progress ...</source>
        <translation>Migration en cours ...</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Fin</translation>
    </message>
    <message>
        <source>Kadu detected, that you were using EKG, GnuGadu or
older version of Kadu before. Would you like to try
to import your settings from %1?</source>
        <translation>Kadu a découvert que vous utilisez EKG, GnuGadu,
ou une version ancienne de Kadu, voulez vous 
importer vos paramètres avec: %1?</translation>
    </message>
    <message>
        <source>Step 1: Migrating settings to kadu directory</source>
        <translation>Vos paramètres sont en cours de la migration dans le catalogue .kadu</translation>
    </message>
    <message>
        <source>Step 1: Settings migrated to kadu directory</source>
        <translation>Étape 1: Vos paramètres ont été transférés dans le catalogue .kadu</translation>
    </message>
    <message>
        <source>Migration process completed. You can remove
%1directory
(backup will be a good idea) or leave it for other applications.</source>
        <translation>La procedure de migration est terminé.
Vous pouvez  éliminer le catalogue:
%1
(veuillez procéder à une sauvegarde, 
cela peut servir pour une autre application).</translation>
    </message>
    <message>
        <source>Error migrating data!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot start migration process!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step 2: Migrating user list to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step 2: User list migrated to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contact list migrated to kadu.conf.xml.You can remove
%1 and
%2 now
(backup will be a good idea).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step 3: Migrating ignored list to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step 3: Ignored list migrated to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignored contact list migrated to kadu.conf.xml.
You can remove %1 now
(backup will be a good idea).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step 4: Migrating config files to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step 4: Config files migrated to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration files migrated to kadu.conf.xml.
You can remove following files now:
%1
(backup will be a good idea).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Migration complete. Kadu will be closed now.
Please click Finish and than run Kadu again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Migration complete.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.orig.tar.gz: kadu/modules/migration/translations/migration_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>MigrationDialog</name>
    <message>
        <location filename="../migration.cpp" line="38"/>
        <source>Migration</source>
        <translation>Migration</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="41"/>
        <source>Migration steps</source>
        <translation> Les étapes de migration</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="46"/>
        <source>Migration in progress ...</source>
        <translation>Migration en cours ...</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="47"/>
        <source>&amp;Finish</source>
        <translation>&amp;Fin</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="108"/>
        <source>Kadu detected, that you were using EKG, GnuGadu or
older version of Kadu before. Would you like to try
to import your settings from %1?</source>
        <translation>Kadu a découvert que vous utilisez EKG, GnuGadu,
ou une version ancienne de Kadu, voulez vous 
importer vos paramètres avec: %1?</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="131"/>
        <source>Step 1: Migrating settings to kadu directory</source>
        <translation>Vos paramètres sont en cours de la migration dans le catalogue .kadu</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="148"/>
        <source>Step 1: Settings migrated to kadu directory</source>
        <translation>Étape 1: Vos paramètres ont été transférés dans le catalogue .kadu</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="151"/>
        <source>Migration process completed. You can remove
%1directory
(backup will be a good idea) or leave it for other applications.</source>
        <translation>La procedure de migration est terminé.
Vous pouvez  éliminer le catalogue:
%1
(veuillez procéder à une sauvegarde, 
cela peut servir pour une autre application).</translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="159"/>
        <source>Error migrating data!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="165"/>
        <source>Cannot start migration process!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="194"/>
        <source>Step 2: Migrating user list to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="200"/>
        <source>Step 2: User list migrated to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="203"/>
        <source>Contact list migrated to kadu.conf.xml.You can remove
%1 and
%2 now
(backup will be a good idea).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="231"/>
        <source>Step 3: Migrating ignored list to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="266"/>
        <source>Step 3: Ignored list migrated to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="269"/>
        <source>Ignored contact list migrated to kadu.conf.xml.
You can remove %1 now
(backup will be a good idea).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="378"/>
        <source>Step 4: Migrating config files to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="399"/>
        <source>Step 4: Config files migrated to kadu.conf.xml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="402"/>
        <source>Configuration files migrated to kadu.conf.xml.
You can remove following files now:
%1
(backup will be a good idea).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="420"/>
        <source>Migration complete. Kadu will be closed now.
Please click Finish and than run Kadu again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../migration.cpp" line="422"/>
        <source>Migration complete.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
